unit uXWordDialog;

{$mode objfpc}{$H+}
{$ModeSwitch advancedrecords}

interface

uses
  SysUtils, Forms, Controls, ExtCtrls, StdCtrls, Spin, ButtonPanel;

type

  { TXWordData }

  TXWordData = record
    title: String;
    author: String;
    cellSize: Integer;
    colCount: Integer;
    rowCount: Integer;
    procedure Init(aTitle, anAuthor: String; aCellSize, aColCount, aRowCount: Integer);
    procedure DisplayData(aMemo: TMemo);
  end;

  { TXWordDialog }

  TXWordDialog = class(TForm)
    AuthorEdit: TEdit;
    ButtonPanel: TButtonPanel;
    CellSizeLabel: TLabel;
    ColumnsLabel: TLabel;
    RowsLabel: TLabel;
    SizeLabel: TLabel;
    CellSizeSpinEdit: TSpinEdit;
    ByRowsLabel: TLabel;
    ColumnsSpinEdit: TSpinEdit;
    DimensionsPanel: TPanel;
    RowsSpinEdit: TSpinEdit;
    TitleEdit: TEdit;
    TitlePanel: TPanel;
    XWordAuthorLabel: TLabel;
    XWordIdentityLabel: TLabel;
    DimensionsLabel: TLabel;
    XWordTitleLabel: TLabel;
    procedure OKButtonClick(Sender: TObject);
  private
    FXWordData: TXWordData;
  public
    property XWordData: TXWordData read FXWordData;
  end;

  function GetXWordDataDlg(out XWordData: TXWordData): Boolean;

implementation

function GetXWordDataDlg(out XWordData: TXWordData): Boolean;
var
  dlg: TXWordDialog;
begin
  XWordData:=Default(TXWordData);
  dlg:=TXWordDialog.Create(Nil);
  try
    Result:=dlg.ShowModal = mrOK;
    if Result then
      XWordData:=dlg.XWordData;
  finally
    dlg.Free;
  end;
end;

{$R *.lfm}

{ TXWordData }

procedure TXWordData.DisplayData(aMemo: TMemo);
begin
  if Assigned(aMemo) then
    begin
      aMemo.Clear;
      with aMemo.Lines do begin
        Add('Data returned by Crossword dialog:');
        Add('  Title: ' + title);
        Add('  Author: ' + author);
        Add(Format('  Cell size: %d',[cellSize]));
        Add(Format('  Col count: %d',[colCount]));
        Add(Format('  Row count: %d',[rowCount]));
      end;
    end;
end;

procedure TXWordData.Init(aTitle, anAuthor: String;
                          aCellSize, aColCount, aRowCount: Integer);
begin
  title:=aTitle;
  author:=anAuthor;
  cellSize:=aCellSize;
  colCount:=aColCount;
  rowCount:=aRowCount;
end;

{ TXWordDialog }

procedure TXWordDialog.OKButtonClick(Sender: TObject);
begin
  FXWordData.Init(TitleEdit.Text, AuthorEdit.Text, CellSizeSpinEdit.Value,
                  ColumnsSpinEdit.Value, RowsSpinEdit.Value);
end;

end.

