unit uPreferencesDlg;

{$mode objfpc}{$H+}
{$ModeSwitch advancedrecords}

interface

uses
  Forms, ComCtrls, StdCtrls, Buttons, Classes;

type

  TVisualisationSize = (vNormal, vLarge, vExtraLarge);

  TVisualisationKind = (vkCorona, vkMonoscope, vkOscilloscope, vkSpectrum);

  { TDisplaySettings }

  TDisplaySettings = record
    newVideoResize: Boolean;
    disableDeinterlacing: Boolean;
    disableScreenSaverBoth: Boolean;
    showVisualEffects: Boolean;
    visualisationKind: TVisualisationKind;
    visualisationSize: TVisualisationSize;
    brightness: Integer;
    contrast: Integer;
    saturation: Integer;
    hue: Integer;
    procedure Init(aNewVideoResize, aDisableInterlacing, aDisableScreenSaverBoth, aShowVisualEffects: Boolean;
                   aVisualisationKind: TVisualisationKind; aVisualisationSize: TVisualisationSize;
                   aBrightness, aContrast, aSaturation, aHue: Integer);
    procedure WriteToMemo(aMemo: TMemo);
  end;

  { TPreferencesDialog }

  TPreferencesDialog = class(TForm)
    BrightnessLabel: TLabel;
    BrightnessTrackBar: TTrackBar;
    CloseBitBtn: TBitBtn;
    ColourBalanceLabel: TLabel;
    ContrastLabel: TLabel;
    ContrastTrackBar: TTrackBar;
    DisableDeinterlacingCheckBox: TCheckBox;
    DisableScreensaverLabel: TLabel;
    DisplayLabel: TLabel;
    HueLabel: TLabel;
    HueTrackBar: TTrackBar;
    PageControl: TPageControl;
    ResetButton: TButton;
    ResizeCheckBox: TCheckBox;
    SaturationLabel: TLabel;
    SaturationTrackBar: TTrackBar;
    tsAudio: TTabSheet;
    tsDisplay: TTabSheet;
    tsGeneral: TTabSheet;
    VideoAudioRadioButton: TRadioButton;
    VideoRadioButton: TRadioButton;
    VisualEffectsCheckBox: TCheckBox;
    VisualEffectsLabel: TLabel;
    VisualisationKindComboBox: TComboBox;
    VisualisationKindLabel: TLabel;
    VisualisationSizeComboBox: TComboBox;
    VisualisationSizeLabel: TLabel;
    procedure CloseBitBtnClick(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word; {%H-}Shift: TShiftState);
    procedure ResetButtonClick(Sender: TObject);
    procedure VisualEffectsCheckBoxChange(Sender: TObject);
  private
    FDisplaySettings: TDisplaySettings;
  public
    property DisplaySettings: TDisplaySettings read FDisplaySettings;
  end;

  function GetDisplaySettingsDlg(out aDisplaySettings: TDisplaySettings): Boolean;

implementation

uses typinfo, sysutils, Controls, LCLType;

function GetDisplaySettingsDlg(out aDisplaySettings: TDisplaySettings): Boolean;
var
  dlg: TPreferencesDialog;
begin
  aDisplaySettings:=Default(TDisplaySettings);
  dlg:=TPreferencesDialog.Create(Nil);
  try
    Result:=dlg.ShowModal = mrOK;
    if Result then
      aDisplaySettings:=dlg.DisplaySettings;
  finally
    dlg.Free;
    dlg:=Nil;
  end;
end;

{$R *.lfm}

{ TPreferencesDialog }

procedure TPreferencesDialog.CloseBitBtnClick(Sender: TObject);
begin
  with FDisplaySettings do begin
    brightness:=BrightnessTrackBar.Position;
    contrast:=ContrastTrackBar.Position;
    disableDeinterlacing:=DisableDeinterlacingCheckBox.Checked;
    disableScreenSaverBoth:=VideoAudioRadioButton.Checked;
    hue:=HueTrackBar.Position;
    newVideoResize:=ResizeCheckBox.Checked;
    saturation:=SaturationTrackBar.Position;
    showVisualEffects:=VisualEffectsCheckBox.Checked;
    if showVisualEffects then begin
      visualisationKind:=TVisualisationKind(VisualisationKindComboBox.ItemIndex);
      visualisationSize:=TVisualisationSize(VisualisationSizeComboBox.ItemIndex);
    end;
  end;
end;

procedure TPreferencesDialog.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  case Key of
    VK_ESCAPE: begin
      Key:=0;
      ModalResult:=mrCancel;
    end;
  end;
end;

procedure TPreferencesDialog.ResetButtonClick(Sender: TObject);
begin
  FDisplaySettings:=Default(TDisplaySettings);
end;

procedure TPreferencesDialog.VisualEffectsCheckBoxChange(Sender: TObject);
var
  bool: Boolean;
begin
  bool:=VisualEffectsCheckBox.Checked;
  VisualisationKindComboBox.Enabled:=bool;
  VisualisationSizeComboBox.Enabled:=bool;
  VisualisationKindLabel.Enabled:=bool;
  VisualisationSizeLabel.Enabled:=bool;
end;

{ TDisplaySettings }

procedure TDisplaySettings.Init(aNewVideoResize, aDisableInterlacing,
  aDisableScreenSaverBoth, aShowVisualEffects: Boolean;
  aVisualisationKind: TVisualisationKind;
  aVisualisationSize: TVisualisationSize; aBrightness, aContrast, aSaturation,
  aHue: Integer);
begin
  newVideoResize:=aNewVideoResize;
  disableDeinterlacing:=aDisableInterlacing;
  disableScreenSaverBoth:=aDisableScreenSaverBoth;
  showVisualEffects:=aShowVisualEffects;
  visualisationKind:=aVisualisationKind;
  visualisationSize:=aVisualisationSize;
  brightness:=aBrightness;
  contrast:=aContrast;
  saturation:=aSaturation;
  hue:=aHue;
end;

procedure TDisplaySettings.WriteToMemo(aMemo: TMemo);
begin
  with aMemo.Lines do begin
    Clear;
    Add('User dialog set values as follows:');
    Add('  newVideoResize=' + BoolToStr(newVideoResize, True));
    Add('  disableInterlacing=' + BoolToStr(disableDeinterlacing, True));
    Add('  disableScreenSaverBoth=' + BoolToStr(disableScreenSaverBoth, True));
    Add('  showVisualEffects=' + BoolToStr(showVisualEffects, True));
    Add('  visualisationKind=' + GetEnumName(TypeInfo(TVisualisationKind), Ord(visualisationKind)));
    Add('  visualisationSize=' + GetEnumName(TypeInfo(TVisualisationSize), Ord(visualisationSize)));
    Add('  brightness=' + IntToStr(brightness));
    Add('  contrast=' + IntToStr(contrast));
    Add('  saturation=' + IntToStr(saturation));
    Add('  hue=' + IntToStr(hue));
  end;
end;

end.

