unit uPreferencesDlgNoLFM;

{$mode objfpc}{$H+}
{$ModeSwitch advancedrecords}

interface

uses
  Forms, ComCtrls, StdCtrls, Buttons, Classes, uPreferencesDlgUtils, Controls;

type

  { TPreferencesDialogNoLFM }

  TPreferencesDialogNoLFM = class(TForm)
  private
    AudioTabSheet: TTabSheet;
    BrightnessLabel: TLabel;
    BrightnessTrackBar: TTrackBar;
    CloseBitBtn: TBitBtn;
    ColourBalanceGroupPanel: TGroupPanel;
    ContrastLabel: TLabel;
    ContrastTrackBar: TTrackBar;
    DisableDeinterlacingCheckBox: TCheckBox;
    DisableScreensaverLabel: TLabel;
    DisplayGroupPanel: TGroupPanel;
    DisplayTabSheet: TTabSheet;
    FDisplaySettings: TDisplaySettings;
    GeneralTabSheet: TTabSheet;
    HueLabel: TLabel;
    HueTrackBar: TTrackBar;
    PageControl: TPageControl;
    ResetButton: TButton;
    ResizeCheckBox: TCheckBox;
    SaturationLabel: TLabel;
    SaturationTrackBar: TTrackBar;
    VideoAudioRadioButton: TRadioButton;
    VideoRadioButton: TRadioButton;
    VisualEffectsCheckBox: TCheckBox;
    VisualEffectsGroupPanel: TGroupPanel;
    VisualisationKindComboBox: TComboBox;
    VisualisationKindLabel: TLabel;
    VisualisationSizeComboBox: TComboBox;
    VisualisationSizeLabel: TLabel;
    procedure CloseBitBtnClick(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word; {%H-}Shift: TShiftState);
    procedure ResetButtonClick(Sender: TObject);
    procedure SetupGUI;
    procedure VisualEffectsCheckBoxChange(Sender: TObject);
  protected
    procedure DoShow; override;
  public
    constructor Create; reintroduce;
    property DisplaySettings: TDisplaySettings read FDisplaySettings;
  end;

  function GetDisplaySettingsDlgNoLFM(out aDisplaySettings: TDisplaySettings): Boolean;

implementation

uses
  LCLType;

function GetDisplaySettingsDlgNoLFM(out aDisplaySettings: TDisplaySettings): Boolean;
var
  dlg: TPreferencesDialogNoLFM;
begin
  aDisplaySettings:=Default(TDisplaySettings);
  dlg:=TPreferencesDialogNoLFM.Create;
  try
    Result:=dlg.ShowModal = mrOK;
    if Result then
      aDisplaySettings:=dlg.DisplaySettings;
  finally
    dlg.Free;
    dlg:=Nil;
  end;
end;

{ TPreferencesDialogNoLFM }

constructor TPreferencesDialogNoLFM.Create;
begin
  inherited CreateNew(Nil);
  Position:=poScreenCenter;
  BorderIcons:=[];
  BorderStyle:=bsDialog;
  Caption:=rsPreferences;
  SetInitialBounds(0, 0, 450, 520);
  Name:='PreferencesDialogNoLFM';
  KeyPreview:=True;
  OnKeyDown:=@FormKeyDown;
  AutoSize:=True;
  PageControl:=TPageControl.Create(Self);
  with PageControl do begin
    Align:=alTop;
    AutoSize:=True;
    BorderSpacing.Around:=10;
    GeneralTabSheet:=AddTabSheet;
    GeneralTabSheet.Caption:=rsGeneral;
    DisplayTabSheet:=AddTabSheet;
    DisplayTabSheet.Caption:=rsDisplay;
    AudioTabSheet:=AddTabSheet;
    AudioTabSheet.Caption:=rsAudio;
    ActivePage:=DisplayTabSheet;
    Parent:=Self;
  end;
  CloseBitBtn:=TBitBtn.Create(Self);
  with CloseBitBtn do begin
    Kind:=bkClose;
    ModalResult:=mrOK;
    Top:=PageControl.BoundsRect.Bottom + Margin;
    Anchors:=[akTop, akRight];
    AnchorSideTop.Control:=PageControl;
    AnchorSideTop.Side:=asrBottom;
    AnchorSideRight.Control:=PageControl;
    AnchorSideRight.Side:=asrRight;
    OnClick:=@CloseBitBtnClick;
    Parent:=Self;
  end;
  SetupGUI;
end;

procedure TPreferencesDialogNoLFM.CloseBitBtnClick(Sender: TObject);
begin
  with FDisplaySettings do begin
    brightness:=BrightnessTrackBar.Position;
    contrast:=ContrastTrackBar.Position;
    disableDeinterlacing:=DisableDeinterlacingCheckBox.Checked;
    disableScreenSaverBoth:=VideoAudioRadioButton.Checked;
    hue:=HueTrackBar.Position;
    newVideoResize:=ResizeCheckBox.Checked;
    saturation:=SaturationTrackBar.Position;
    showVisualEffects:=VisualEffectsCheckBox.Checked;
    if showVisualEffects then begin
      visualisationKind:=TVisualisationKind(VisualisationKindComboBox.ItemIndex);
      visualisationSize:=TVisualisationSize(VisualisationSizeComboBox.ItemIndex);
    end;
  end;
end;

procedure TPreferencesDialogNoLFM.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  case Key of
    VK_ESCAPE: begin
      Key:=0;
      ModalResult:=mrCancel;
    end;
  end;
end;

procedure TPreferencesDialogNoLFM.ResetButtonClick(Sender: TObject);
begin
  FDisplaySettings:=Default(TDisplaySettings);
  with FDisplaySettings do begin
    BrightnessTrackBar.Position:=brightness;
    ContrastTrackBar.Position:=contrast;
    DisableDeinterlacingCheckBox.Checked:=disableDeinterlacing;
    VideoRadioButton.Checked:=not disableScreenSaverBoth;
    HueTrackBar.Position:=hue;
    ResizeCheckBox.Checked:=newVideoResize;
    SaturationTrackBar.Position:=saturation;
    VisualEffectsCheckBox.Checked:=showVisualEffects;
    if VisualEffectsCheckBox.Checked then begin
      VisualisationKindComboBox.ItemIndex:=Integer(visualisationKind);
      VisualisationSizeComboBox.ItemIndex:=Integer(visualisationSize);
    end;
  end;
end;

procedure TPreferencesDialogNoLFM.SetupGUI;
begin
  DisplayGroupPanel:=TGroupPanel.Create(Self, rsDisplay);
  with DisplayGroupPanel do begin
    AnchorSideTop.Control:=DisplayTabSheet;
    BorderSpacing.Around:=Margin;
    Parent:=DisplayTabSheet;
  end;
  ResizeCheckBox:=TCheckBox.Create(Self);
  with ResizeCheckBox do begin
    AnchorSideLeft.Control:=DisplayGroupPanel;
    AnchorSideTop.Control:=DisplayGroupPanel.Title;
    AnchorSideTop.Side:=asrBottom;
    BorderSpacing.Top:=HalfMargin;
    BorderSpacing.Left:=Margin;
    BorderSpacing.Bottom:=HalfMargin;
    Caption:=rsResizeTheWindowWhenA;
    Parent:=DisplayGroupPanel;
  end;
  DisableDeinterlacingCheckBox:=TCheckBox.Create(Self);
  with DisableDeinterlacingCheckBox do begin
    AnchorSideLeft.Control:=ResizeCheckBox;
    AnchorSideTop.Control:=ResizeCheckBox;
    AnchorSideTop.Side:=asrBottom;
    Caption:=rsDisableDeinterlacing;
    Parent:=DisplayGroupPanel;
  end;
  DisableScreensaverLabel:=TLabel.Create(Self);
  with DisableScreensaverLabel do begin
    AnchorSideLeft.Control:=DisableDeinterlacingCheckBox;
    AnchorSideTop.Control:=DisableDeinterlacingCheckBox;
    AnchorSideTop.Side:=asrBottom;
    BorderSpacing.Left:=2;
    BorderSpacing.Top:=5;
    Caption:=rsDisableScreensaverWh;
    Parent:=DisplayGroupPanel;
  end;
  VideoRadioButton:=TRadioButton.Create(Self);
  with VideoRadioButton do begin
    AnchorSideLeft.Control:=DisableScreensaverLabel;
    AnchorSideLeft.Side:=asrBottom;
    AnchorSideTop.Control:=DisableScreensaverLabel;
    AnchorSideTop.Side:=asrCenter;
    BorderSpacing.Left:=Margin;
    Caption:=rsVideo;
    Checked:=True;
    Parent:=DisplayGroupPanel;
  end;
  VideoAudioRadioButton:=TRadioButton.Create(Self);
  with VideoAudioRadioButton do begin
    AnchorSideLeft.Control:=VideoRadioButton;
    AnchorSideLeft.Side:=asrBottom;
    AnchorSideTop.Control:=VideoRadioButton;
    AnchorSideTop.Side:=asrCenter;
    BorderSpacing.Left:=8;
    Caption:=rsVideoOrAudio;
    Parent:=DisplayGroupPanel;
  end;

  VisualEffectsGroupPanel:=TGroupPanel.Create(Self, rsVisualEffects);
  with VisualEffectsGroupPanel do begin
    Anchors:=[akLeft, akTop, akRight];
    AnchorSideLeft.Control:=DisplayTabSheet;
    AnchorSideTop.Control:=DisplayGroupPanel;
    AnchorSideTop.Side:=asrBottom;
    AnchorSideRight.Control:=DisplayTabSheet;
    AnchorSideRight.Side:=asrRight;
    BorderSpacing.Around:=10;
    Parent:=DisplayTabSheet;
  end;
  VisualEffectsCheckBox:=TCheckBox.Create(Self);
  with VisualEffectsCheckBox do begin
    AnchorSideLeft.Control:=VisualEffectsGroupPanel;
    AnchorSideTop.Control:=VisualEffectsGroupPanel.Title;
    AnchorSideTop.Side:=asrBottom;
    BorderSpacing.Top:=HalfMargin;
    BorderSpacing.Left:=Margin;
    BorderSpacing.Bottom:=HalfMargin;
    Caption:=rsShowVisualEffectsWhe;
    OnChange:=@VisualEffectsCheckBoxChange;
    Parent:=VisualEffectsGroupPanel;
  end;
  VisualisationKindComboBox:=TComboBox.Create(Self);
  with VisualisationKindComboBox do begin
    Anchors:=[akTop, akRight, akLeft];
    AnchorSideLeft.Side:=asrRight;
    AnchorSideTop.Control:=VisualEffectsCheckBox;
    AnchorSideTop.Side:=asrBottom;
    AnchorSideRight.Control:=VisualEffectsGroupPanel;
    AnchorSideRight.Side:=asrRight;
    BorderSpacing.Left:=Margin;
    Enabled:=False;
    Items.CommaText:=rsCoronaMonoscopeOscil;
    ItemIndex:=0;
    Parent:=VisualEffectsGroupPanel;
  end;
  VisualisationKindLabel:=TLabel.Create(Self);
  with VisualisationKindLabel do begin
    AnchorSideLeft.Control:=VisualEffectsCheckBox;
    AnchorSideTop.Control:=VisualisationKindComboBox;
    AnchorSideTop.Side:=asrCenter;
    BorderSpacing.Left:=2;
    Caption:=rsTypeOfVisualisation;
    Enabled:=False;
    Parent:=VisualEffectsGroupPanel;
  end;
  VisualisationKindComboBox.AnchorSideLeft.Control:=VisualisationKindLabel;
  VisualisationSizeComboBox:=TComboBox.Create(Self);
  with VisualisationSizeComboBox do begin
    Anchors:=[akTop, akRight, akLeft];
    AnchorSideLeft.Control:=VisualisationKindComboBox;
    AnchorSideTop.Control:=VisualisationKindComboBox;
    AnchorSideTop.Side:=asrBottom;
    AnchorSideRight.Control:=VisualisationKindComboBox;
    AnchorSideRight.Side:=asrRight;
    BorderSpacing.Top:=5;
    Enabled:=False;
    Items.CommaText:=rsNormalLargeExtraLarg;
    ItemIndex:=0;
    Parent:=VisualEffectsGroupPanel;
  end;
  VisualisationSizeLabel:=TLabel.Create(Self);
  with VisualisationSizeLabel do begin
    AnchorSideLeft.Control:=VisualisationKindLabel;
    AnchorSideTop.Control:=VisualisationSizeComboBox;
    AnchorSideTop.Side:=asrCenter;
    Caption:=rsVisualisationSize;
    Enabled:=False;
    Parent:=VisualEffectsGroupPanel;
  end;

  ColourBalanceGroupPanel:=TGroupPanel.Create(Self, rsColourBalance);
  with ColourBalanceGroupPanel do begin
    Anchors:=[akLeft, akTop, akRight];
    AnchorSideTop.Control:=VisualEffectsGroupPanel;
    AnchorSideTop.Side:=asrBottom;
    AnchorSideRight.Control:=DisplayTabSheet;
    AnchorSideRight.Side:=asrRight;
    BorderSpacing.Left:=Margin;
    BorderSpacing.Bottom:=HalfMargin;
    Parent:=DisplayTabSheet;
  end;
  BrightnessLabel:=TLabel.Create(Self);
  with BrightnessLabel do begin
    AnchorSideLeft.Control:=ColourBalanceGroupPanel;
    BorderSpacing.Around:=HalfMargin;
    BorderSpacing.Left:=Margin;
    AnchorSideTop.Control:=ColourBalanceGroupPanel.Title;
    AnchorSideTop.Side:=asrBottom;
    Caption:=rsBrightness;
    Parent:=ColourBalanceGroupPanel;
  end;
  BrightnessTrackBar:=TTrackBar.Create(Self);
  with BrightnessTrackBar do begin
    Anchors:=[akTop, akLeft, akRight];
    AnchorSideLeft.Control:=ColourBalanceGroupPanel.Title;
    AnchorSideLeft.Side:=asrRight;
    AnchorSideTop.Control:=BrightnessLabel;
    AnchorSideTop.Side:=asrCenter;
    AnchorSideRight.Control:=ColourBalanceGroupPanel;
    AnchorSideRight.Side:=asrRight;
    Position:=5;
    TickStyle:=tsNone;
    Parent:=ColourBalanceGroupPanel;
  end;
  ContrastLabel:=TLabel.Create(Self);
  with ContrastLabel do begin
    AnchorSideLeft.Control:=BrightnessLabel;
    AnchorSideTop.Control:=BrightnessLabel;
    AnchorSideTop.Side:=asrBottom;
    BorderSpacing.Top:=Margin;
    Caption:=rsContrast;
    Parent:=ColourBalanceGroupPanel;
  end;
  ContrastTrackBar:=TTrackBar.Create(Self);
  with ContrastTrackBar do begin
    Anchors:=[akLeft, akRight, akTop];
    AnchorSideLeft.Control:=BrightnessTrackBar;
    AnchorSideTop.Control:=ContrastLabel;
    AnchorSideTop.Side:=asrCenter;
    AnchorSideRight.Control:=BrightnessTrackBar;
    AnchorSideRight.Side:=asrRight;
    Position:=5;
    TickStyle:=tsNone;
    Parent:=ColourBalanceGroupPanel;
  end;
  SaturationLabel:=TLabel.Create(Self);
  with SaturationLabel do begin
    AnchorSideLeft.Control:=ContrastLabel;
    AnchorSideTop.Control:=ContrastLabel;
    AnchorSideTop.Side:=asrBottom;
    BorderSpacing.top:=Margin;
    Caption:=rsSaturation;
    Parent:=ColourBalanceGroupPanel;
  end;
  SaturationTrackBar:=TTrackBar.Create(Self);
  with SaturationTrackBar do begin
    Anchors:=[akLeft, akRight, akTop];
    AnchorSideLeft.Control:=ContrastTrackBar;
    AnchorSideTop.Control:=SaturationLabel;
    AnchorSideTop.Side:=asrCenter;
    AnchorSideRight.Control:=BrightnessTrackBar;
    AnchorSideRight.Side:=asrRight;
    Position:=5;
    TickStyle:=tsNone;
    Parent:=ColourBalanceGroupPanel;
  end;
  HueLabel:=TLabel.Create(Self);
  with HueLabel do begin
    BorderSpacing.Top:=Margin;
    AnchorSideLeft.Control:=SaturationLabel;
    AnchorSideTop.Control:=SaturationLabel;
    AnchorSideTop.Side:=asrBottom;
    Caption:=rsHue;
    Parent:=ColourBalanceGroupPanel;
  end;
  HueTrackBar:=TTrackBar.Create(Self);
  with HueTrackBar do begin
    Anchors:=[akLeft, akRight, akTop];
    AnchorSideLeft.Control:=BrightnessTrackBar;
    AnchorSideTop.Control:=HueLabel;
    AnchorSideTop.Side:=asrCenter;
    AnchorSideRight.Control:=BrightnessTrackBar;
    AnchorSideRight.Side:=asrRight;
    Position:=5;
    TickStyle:=tsNone;
    Parent:=ColourBalanceGroupPanel;
  end;

  ResetButton:=TButton.Create(Self);
  with ResetButton do begin
    Anchors:=[akTop, akRight];
    BorderSpacing.Top:=Margin;
    AnchorSideTop.Control:=HueTrackBar;
    AnchorSideTop.Side:=asrBottom;
    AnchorSideRight.Control:=HueTrackBar;
    AnchorSideRight.Side:=asrRight;
    AutoSize:=True;
    Caption:=rsResetToDefaults;
    OnClick:=@ResetButtonClick;
    Parent:=ColourBalanceGroupPanel;
  end;
end;

procedure TPreferencesDialogNoLFM.VisualEffectsCheckBoxChange(Sender: TObject);
var
  bool: Boolean;
begin
  bool:=VisualEffectsCheckBox.Checked;
  VisualisationKindComboBox.Enabled:=bool;
  VisualisationSizeComboBox.Enabled:=bool;
  VisualisationKindLabel.Enabled:=bool;
  VisualisationSizeLabel.Enabled:=bool;
end;

procedure TPreferencesDialogNoLFM.DoShow;
begin
  inherited DoShow;
  Constraints.MinHeight:=CloseBitBtn.BoundsRect.Bottom + Margin;
end;

end.

